@@ -156,6 +156,9 @@ class IPythonConsole(SpyderPluginWidget):
         The new working directory path.
     """
 
+    # Remove when this plugin is migrated
+    sig_exception_occurred = Signal(dict)
+
     # Error messages
     permission_error_msg = _("The directory {} is not writable and it is "
                              "required to create IPython consoles. Please "
@@ -998,9 +1001,9 @@ class IPythonConsole(SpyderPluginWidget):
                       "create a console for you.<br><br>"
                       "You can install it by running in a system terminal:"
                       "<br><br>"
-                      "<tt>conda install spyder-kernels</tt>"
+                      "<tt>conda install spyder-kernels=2.0</tt>"
                       "<br><br>or<br><br>"
-                      "<tt>pip install spyder-kernels</tt>")
+                      "<tt>pip install spyder-kernels==2.0.*</tt>")
                 )
                 return
 
@@ -1063,7 +1066,7 @@ class IPythonConsole(SpyderPluginWidget):
         shellwidget = client.shellwidget
         shellwidget.set_kernel_client_and_manager(kc, km)
         shellwidget.sig_exception_occurred.connect(
-            self.main.console.handle_exception)
+            self.sig_exception_occurred)
 
     @Slot(object, object)
     def edit_file(self, filename, line):
@@ -1199,7 +1202,7 @@ class IPythonConsole(SpyderPluginWidget):
         shellwidget.new_client.connect(self.create_new_client)
 
         # For tracebacks
-        control.go_to_error.connect(self.go_to_error)
+        control.sig_go_to_error_requested.connect(self.go_to_error)
 
         # For help requests
         control.sig_help_requested.connect(self.sig_help_requested)
@@ -1852,7 +1855,7 @@ class IPythonConsole(SpyderPluginWidget):
         shellwidget.set_kernel_client_and_manager(
             kernel_client, kernel_manager)
         shellwidget.sig_exception_occurred.connect(
-            self.main.console.handle_exception)
+            self.sig_exception_occurred)
 
         if external_kernel:
             shellwidget.sig_is_spykernel.connect(
